@@ -69,7 +69,7 @@ class Episode(object):
                 try:
                     summary = re.search(
                         r"</script><br>(.*?)<br>", page,
-                        re.MULTILINE).group(1).strip()
+                        re.MULTILINE | re.DOTALL).group(1).strip()
                     return unicode(summary, 'utf-8')
                 except Exception, e:
                     print('Episode.summary: %s, %s' % (self, e))
@@ -128,15 +128,13 @@ class Show(object):
         show = feeds.search(self.shortname, node='show')
         # dynamically mapping the xml tags to properties:
         for elem in show:
-            # Don't set these yet
-            if elem.tag in ('seasons', ):
-                continue
-            # these properties should be ints
-            elif elem.tag in ('started', 'ended'):
-                self.__dict__[elem.tag] = int(elem.text)
-            # these are fine as strings
-            else:
-                self.__dict__[elem.tag] = elem.text
+            if not elem.tag == 'seasons': # we'll set this later 
+                # these properties should be ints
+                if elem.tag in ('started', 'ended'):
+                    self.__dict__[elem.tag] = int(elem.text)
+                # these are fine as strings
+                else:
+                    self.__dict__[elem.tag] = elem.text
         self.genres = [g.text for g in show.find('genres')]
 
         # and now grabbing the episodes
@@ -183,20 +181,22 @@ class Show(object):
 
     @property
     def next_episode(self):
-        """returns the next upcomming episode"""
+        """returns the next upcoming episode"""
         try:
-            return self.upcomming_episodes.next()
+            return self.upcoming_episodes.next()
         except StopIteration:
             raise NoNewEpisodesAnnounced, self.name
 
     @property
-    def upcomming_episodes(self):
-        """returns all upcomming episodes that have been annouced yet"""
+    def upcoming_episodes(self):
+        """returns all upcoming episodes that have been annouced yet"""
         today = date.today()
         for e in self.current_season.values():
             if (e.airdate != None) and (e.airdate >= today):
                 yield e
 
+    upcomming_episodes = upcoming_episodes
+
     @property
     def latest_episode(self):
         """returns the latest episode that has aired already"""
